@@ -145,7 +145,7 @@ def setup_redis_worker(env: str) -> Tuple:
     return redis_worker
 
 
-def get_config_by_id(string_id: str, collection: str) -> [dict, None]:
+def get_config_by_id(string_id: str, collection: str) -> Union[dict, None]:
     """
     Get the drillstring or casingstring from API by providing mongodb _id
     :param string_id: mongodb _id of the drillstring
