@@ -25,7 +25,7 @@ class SectionsMixin(object):
         return "\n".join(str(sec) for sec in self.sections)
 
     def find_section_at_measured_depth(self, measured_depth: float,
-                                       at_exact_measured_depth: bool) -> Union[HoleSection, Ann, Pipe, None]:
+                                       at_exact_measured_depth: bool = False) -> Union[HoleSection, Ann, Pipe, None]:
         """
         :param measured_depth:
         :param at_exact_measured_depth:
